@@ -22,23 +22,29 @@ use strict;
 use warnings;
 use Data::Dumper;
 
-use Getopt::EX::termcolor qw(rgb_to_brightness);
+use Getopt::EX::termcolor qw(rgb_to_luminance);
 
-sub rgb {
+sub get_colors {
+    map {
+	my @rgb = get_color($_);
+	@rgb ? undef : [ @rgb ];
+    } @_;
+}
+
+sub get_color {
+    my $cat = lc shift;
+    if ($cat eq 'background') {
+	return background_rgb();
+    }
+    ();
+}
+
+sub background_rgb {
     my $app = "Terminal";
     my $do = "background color of first window";
     my $bg = qx{osascript -e \'tell application \"$app\" to $do\'};
-    $bg =~ /(\d+)/g;
-}
-
-sub brightness {
-    my(@rgb) = rgb;
-    @rgb == 3 or return undef;
-    if (grep { not /^\d+$/ } @rgb) {
-	undef;
-    } else {
-	rgb_to_brightness @rgb;
-    }
+    my @rgb = $bg =~ /(\d+)/g;
+    @rgb == 3 ? ( { max => 65535 }, @rgb) : ();
 }
 
 1;
